@@ -100,6 +100,41 @@ tape('newsfeed index includes encrypted messages', function (t) {
   })
 })
 
+tape('newsfeed correctly orders despite bad timestamps', function (t) {
+  var sbot = u.newserver()
+  var users = {
+    alice: ssbkeys.generate(),
+    bob: ssbkeys.generate(),
+    charlie: ssbkeys.generate()
+  }
+
+  // TS ahead by 2 hours
+  sbot.add(u.customTimeCreateMsg(users.alice, Date.now() + 1000*60*60*2, { type: 'post', text: 'a' }), function (err, msgA) {
+    if (err) throw err
+
+    // TS ahead by an hour
+    sbot.add(u.customTimeCreateMsg(users.bob, Date.now() + 1000*60*60, { type: 'post', text: 'b' }), function (err, msgB) {
+      if (err) throw err
+
+      // TS correct
+      sbot.add(u.customTimeCreateMsg(users.charlie, Date.now(), { type: 'post', text: 'c' }), function (err, msgC) {
+        if (err) throw err
+
+        pull(sbot.patchwork.createNewsfeedStream(), pull.collect(function (err, msgs) {
+          if (err) throw err
+          t.equal(msgs.length, 3)
+          // still ordered by most-recent-additions first
+          t.equal(msgs[0].key, msgC.key)
+          t.equal(msgs[1].key, msgB.key)
+          t.equal(msgs[2].key, msgA.key)
+          t.end()
+          sbot.close()
+        }))
+      })
+    })
+  })
+})
+
 tape('inbox index doesnt include public threads', function (t) {
   var sbot = u.newserver()
   u.makeusers(sbot, {
@@ -695,4 +730,100 @@ tape('notifications index includes messages which mention the local user', funct
       }))
     })
   })
+})
+
+tape('channel index created when used', function (t) {
+  var sbot = u.newserver()
+  u.makeusers(sbot, {
+    alice: {},
+    bob: {},
+    charlie: {}
+  }, function (err, users) {
+    if (err) throw err
+
+    var done = multicb()
+    users.alice.add({ type: 'post', text: 'hello from alice', channel: 'channel-a' }, done())
+    users.bob.add({ type: 'post', text: 'hello from bob', channel: 'channel-a' }, done())
+    users.charlie.add({ type: 'post', text: 'hello from charlie', channel: 'the b channel' }, done())
+    done(function (err) {
+      if (err) throw err
+
+      pull(sbot.patchwork.createChannelStream('channel-a'), pull.collect(function (err, msgs) {
+        if (err) throw err
+        t.equal(msgs.length, 2)
+
+        pull(sbot.patchwork.createChannelStream('the b channel'), pull.collect(function (err, msgs) {
+          if (err) throw err
+          t.equal(msgs.length, 1)
+
+          sbot.patchwork.getIndexCounts(function (err, counts) {
+            if (err) throw err
+            t.equal(counts['channel-channel-a'], 2)
+            t.equal(counts['channel-the b channel'], 1)
+            t.end()
+            sbot.close()
+          })
+        }))
+      }))
+    })
+  })
+})
+
+tape('channel index gives empty results when not yet used', function (t) {
+  var sbot = u.newserver()
+  u.makeusers(sbot, {
+    alice: {},
+    bob: {},
+    charlie: {}
+  }, function (err, users) {
+    if (err) throw err
+
+    pull(sbot.patchwork.createChannelStream('some random, unused channel'), pull.collect(function (err, msgs) {
+      if (err) throw err
+      t.equal(msgs.length, 0)
+      t.end()
+      sbot.close()
+    }))
+  })
+})
+
+tape('channel index reorders correctly on replies', function (t) {
+  var sbot = u.newserver()
+  u.makeusers(sbot, {
+    alice: {},
+    bob: {},
+    charlie: {}
+  }, function (err, users) {
+    if (err) throw err
+
+    users.alice.add({ type: 'post', text: 'hello from alice', channel: 'the channel' }, function (err, msgA) {
+      if (err) throw err
+
+      users.charlie.add({ type: 'post', text: 'hello from charlie', channel: 'the channel' }, function (err, msgB) {
+        if (err) throw err
+
+        pull(sbot.patchwork.createChannelStream('the channel', { threads: true }), pull.collect(function (err, msgs) {
+          if (err) throw err
+          t.equal(msgs.length, 2)
+          // most recent post is first
+          t.equal(msgs[0].key, msgB.key)
+          t.equal(msgs[1].key, msgA.key)
+
+          users.bob.add({ type: 'post', text: 'reply from bob', root: msgA.key, branch: msgA.key, channel: 'the channel' }, function (err, reply) {
+            if (err) throw err
+
+            pull(sbot.patchwork.createChannelStream('the channel', { threads: true }), pull.collect(function (err, msgs) {
+              if (err) throw err
+              t.equal(msgs.length, 2)
+              // reordered due to reply
+              t.equal(msgs[0].key, msgA.key)
+              t.equal(msgs[1].key, msgB.key)
+              t.end()
+              sbot.close()
+            }))
+          })
+        }))
+      })
+    })
+  })
 })
\ No newline at end of file
