@@ -1,8 +1,5 @@
 'use strict'
 
-// install babel hooks
-require('babel/register')
-
 var pull     = require('pull-stream')
 var ReactDOM = require('react-dom')
 
@@ -14,11 +11,11 @@ window.app = require('./lib/app')
 
 // toplevel events
 window.addEventListener('error', onError)
-window.addEventListener('contextmenu', require('./contextmenu'))
 
 // render
 app.fetchLatestState(function () {
-  ReactDOM.render(require('./routes.jsx'), document.body.querySelector('div'))
+  var routes = require('./routes.jsx')
+  ReactDOM.render(routes.routes, document.body.querySelector('div'))
   window.removeEventListener('error', window.loadErrorHandler)
 })
 
@@ -27,5 +24,5 @@ app.fetchLatestState(function () {
 
 function onError (e) {
   e.preventDefault()
-  app.minorIssue('Unexpected Error', e.error, 'This was an unhandled exception.')
+  app.minorIssue('Unexpected Error', e.error || e, 'This was an unhandled exception.')
 }
\ No newline at end of file
