@@ -8,10 +8,6 @@ import u from '../lib/util'
 export default class Msg extends React.Component {
   render() {
     const id = this.props.params && this.props.params.id
-    return <div id="msg">
-      { id
-        ? <Thread id={id} live />
-        : <div style={{padding: 20, fontWeight: 300, textAlign:'center'}}>No thread selected.</div> }
-    </div>
+    return <div id="msg"><Thread id={id} live /></div>
   }
 }
\ No newline at end of file
